``lxm3.xm_cluster``
===================

``lxm3.xm_cluster.executable_specs``
####################################

.. autosummary::
   :toctree: _autosummary

   lxm3.xm_cluster.ModuleName
   lxm3.xm_cluster.CommandList
   lxm3.xm_cluster.Fileset
   lxm3.xm_cluster.PythonPackage
   lxm3.xm_cluster.UniversalPackage
   lxm3.xm_cluster.SingularityContainer

``lxm3.xm_cluster.executors``
#############################
.. autosummary::
   :toctree: _autosummary

   lxm3.xm_cluster.SingularityOptions
   lxm3.xm_cluster.JobRequirements
   lxm3.xm_cluster.Local
   lxm3.xm_cluster.Slurm
   lxm3.xm_cluster.GridEngine

``lxm3.xm_cluster.experiment``
##############################

.. autosummary::
   lxm3.xm_cluster.create_experiment
